import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import React, { useState } from 'react';
import { usePopper } from "react-popper";
// import { Portal } from "./Portal";
import { animated, useTransition } from "react-spring";
import PropTypes from "prop-types";
import { mergeRefs } from "./Hooks/merge-refs";
import { css } from "@emotion/react";
import { useTheme } from "./Theme/Providers";
import { LayerRefComp } from "./Layer";
// import {Text} from "./Text";
// import {arrowStyles} from "./Tooltip";
//新的是“data-popper-placement” 旧版&[data-placement*='bottom'] { 是‘data-placement’
//底下&[data-popper-placement*='bottom'] {实际是给了arrowDIV的，但要对其父辈Div被选择到&[data-popper-placement*='bottom']选定样式目标。否则无效的。
export const arrowStyles = (color) => css(`
  position: absolute;
  width: 3em;
  height: 3em;
  &[data-popper-placement*='bottom'] {
    bottom: 100%;
    left: 0;
    margin-top: 0em;
    width: 1em;
    height: 0.25em;
    &::before {
      width: 10px;
      border: none;
      height: 10px;
      background: ${color};
      border-top: 1px solid ${color === "white" ? " #dee2e685" : color};
      border-right: 1px solid ${color === "white" ? "#dee2e685" : color};
      transform: rotate(-45deg);
      border-radius: 2px;
      margin-top: -1px;
    }
  }
  &[data-popper-placement*='top'] {
    top: 100%;
    left: 0;
    margin-bottom: 0;
    width: 1em;
    height: 0.25em;
    &::before {
      border-width: 0.25em 0.25em 0 0.25em;
      border-color: ${color} transparent transparent transparent;
    }
  }
  &[data-popper-placement*='right'] {
    right: 100%;
    height: 1em;
    width: 0.25em;
    &::before {
      border-width: 0.25em 0.25em 0.25em 0;
      border-color: transparent ${color} transparent transparent;
    }
  }
  &[data-popper-placement*='left'] {
    left: 100%;
    height: 1em;
    width: 0.25em;
    &::before {
      border-width: 0.25em 0 0.25em 0.25em;
      border-color: transparent transparent transparent ${color};
    }
  }
  &::before {
    content: '';
    margin: auto;
    display: block;
    width: 0;
    height: 0;
    border-style: solid;
  }
`);
//动画效果;
//const AnimatedLayer = animated(Layer) as React.FunctionComponent<any>;
//必须要传递 ref，否则无法满足 Positioner内 react-popper:的 Popper 组件需要innerRef参数的要求。
const AnimatedLayer = animated(LayerRefComp);
/** 原来是在Tooltip 和 Popover两个使用到了。
* */
export const Positioner = ({ target, isOpen = true, children, placement, isTip = false, bgColor, ...other }) => {
    const theme = useTheme();
    const transitions = useTransition(isOpen, {
        from: { opacity: 1 },
        // keys: item => item.key,
        enter: { opacity: 1 },
        leave: { opacity: 0 },
        config: { mass: 1, tension: 185, friction: 26 }
    });
    //改为2.3版本popper的： 旧的用<Positioner组件;
    const [referenceElement, setReferenceElement] = useState(null);
    const [popperElement, setPopperElement] = useState(null);
    const [arrowElement, setArrowElement] = useState(null);
    const { styles, attributes } = usePopper(referenceElement, popperElement, {
        modifiers: [{ name: 'arrow', options: { element: arrowElement } }],
        placement,
    });
    //实际控制用3个Ref+2个样式+1个属性：data-popper-reference-hidden="false" data-popper-escaped="false" data-popper-placement="bottom"
    //底下2个样式注入，另外{...attributes.popper}会生成3个属性：data-popper-placement=“” data-popper-escaped data-popper-reference-hidden="false"
    return (_jsxs(React.Fragment, { children: [
            //被关注或附着得的按钮本身 render：
            target({
                ref: mergeRefs(setReferenceElement),
            }), //动画效果版的Popper后面两个Div: 参考的https://popper.js.org/react-popper/v2/
            transitions((style, item) => {
                return (item &&
                    _jsxs(AnimatedLayer
                    //data-popper-placement={placement}
                    , { 
                        //data-popper-placement={placement}
                        role: "dialog", className: "Positioner", ref: setPopperElement, style: {
                            ...styles.popper,
                            opacity: style.opacity
                        }, css: {
                            zIndex: theme.zIndices.tooltip,
                            margin: theme.spaces.xs,
                            //boxShadow: 'unset',
                        }, ...attributes.popper, ...other, children: [_jsx("div", { className: "Positioner_arrow", ref: setArrowElement, style: styles.arrow, css: arrowStyles(bgColor), ...attributes.popper }), children] }));
            })] }));
};
Positioner.propTypes = {
    isOpen: PropTypes.bool,
    placement: PropTypes.oneOf([
        "auto-start",
        "auto",
        "auto-end",
        "top-start",
        "top",
        "top-end",
        "right-start",
        "right",
        "right-end",
        "bottom-end",
        "bottom",
        "bottom-start",
        "left-end",
        "left",
        "left-start"
    ]),
    target: PropTypes.func,
    children: PropTypes.node
};
//# sourceMappingURL=Positions.js.map