import * as React from "react";
/**
 * A Table provides a useful abstraction for managing rows and columns.
 */
interface TableProps extends React.HTMLAttributes<HTMLTableElement> {
    /** An optional minimum width for table content.
     * 配置表格的最小宽度，小于它就启用水平滚动条。 举例：minWidth=css 单位。
     *  */
    minWidth?: string;
    /** An optional array of fixed layout widths for each column
     * 非打印场景的必须看fixed； 打印场景优先使用printColWidth；若这两者都没定义那就是系统自动的。
     * 百分比% 和数值px两种形式。 举例：fixed={["8%","23%","%","12%"] }  printColWidth={["60","156","700","80"]}
     * */
    fixed?: string[];
    printColWidth?: string[];
}
/**
支持打印自适应，支持手机自适应。
 */
export declare const Table: React.FunctionComponent<TableProps>;
/**
 * A TableHead is used to render column labels in a table.
 */
type TableHeadProps = React.HTMLAttributes<HTMLTableSectionElement>;
export declare function TableHead({ children, ...other }: TableHeadProps): import("@emotion/react/jsx-runtime").JSX.Element;
interface TableRowProps extends React.HTMLAttributes<HTMLTableRowElement> {
    /** A callback when a row is selected */
    onClick?: () => void;
}
export declare const TableRow: React.FunctionComponent<TableRowProps>;
type AlignCellType = "right" | "left" | "center" | "justify";
type tableCellVariants = "head" | "body";
type TableCellBaseProps = React.ThHTMLAttributes<HTMLTableHeaderCellElement> & React.TdHTMLAttributes<HTMLTableDataCellElement>;
interface TableCellProps extends TableCellBaseProps {
    align?: AlignCellType;
    variant?: tableCellVariants;
    ellipsis?: boolean;
    component?: React.ElementType<TableCellBaseProps>;
}
/**
 * 旧版本的Cell组件，新版本改用Cell; 两个版本的样式不一样
 */
export declare const TableCell: React.FunctionComponent<TableCellProps>;
/**
 * 新版 TableCell 组件，支持手机上作表格形式的报告，支持打印。
 * 做报表用的样式, CCell, RCell类似 Cell,就差align格式;
 * 旧版本请用TableCell组件,两个版本的样式不一样
 */
export declare const Cell: React.FunctionComponent<TableCellProps>;
/**
 * TableBody - indicates the body (and scrollable) portion of our table.
 */
type TableBodyProps = React.HTMLAttributes<HTMLTableSectionElement>;
export declare function TableBody({ children, ...other }: TableBodyProps): import("@emotion/react/jsx-runtime").JSX.Element;
/**
 * An ExpandingRow displays additional content about the row when clicked.
 */
interface ExpandingRowProps {
    /** The expanded content to show when the user selects the row */
    content: (close: () => void) => React.ReactNode | React.ReactNode;
    children: React.ReactNode;
}
export declare const ExpandingRow: React.FunctionComponent<ExpandingRowProps>;
/**
大量重复的组件标签，简化: CCell代表居中显示的Cell
 */
export declare const CCell: React.FunctionComponent<TableCellProps>;
/**做点简化，免得看起来是一大堆重复性质代码：
 * 代表靠右边 显示的Cell
 */
export declare const RCell: React.FunctionComponent<TableCellProps>;
export {};
