import * as React from "react";
import { Theme } from "./Theme";
export declare const getVariantStyles: (theme: Theme, variant: TextVariants) => import("@emotion/utils").SerializedStyles;
export type TextVariants = "uppercase" | "hidden" | "body" | "paragraph" | "subtitle" | "lead" | "h6" | "h5" | "h4" | "h3" | "h2" | "h1" | "display3" | "display2" | "display1";
export interface TextProps extends React.HTMLAttributes<HTMLElement> {
    /** The text style */
    variant?: TextVariants;
    /** Use text-overflow: ellipsis styling when set to false */
    wrap?: boolean;
    /** Use muted colors */
    muted?: boolean;
    /** Set to false to remove any bottom margins */
    gutter?: boolean;
    component?: React.ElementType<TextProps>;
}
export declare const Text: React.FunctionComponent<TextProps>;
/**针对多个连续<Text>文本之间毫无一点点的间隙定制一个简化组件。
 * 特殊版<Text>； 水平方向的固定 margin: '0 0.2rem'
 * */
export declare const Itext: React.FunctionComponent<TextProps>;
export interface LabelTextProps extends TextProps {
    /**关联的input ID*/
    htmlFor?: string;
}
/**
 * 专门给label搞个Text,融合版本,可指定 for="input_id"
 * htmlFor是个关键参数，用途较大。
 * ...other包含文字string, 本来的纯粹文字或Text描述label 或 children。
 * LabelText代替 <Label>嵌套<Text>的组合方式,减少少标签div嵌套层数可简化，功能替代，优化目的=提高性能。
 */
export declare const LabelText: React.FunctionComponent<LabelTextProps>;
