import * as React from "react";
import { OnPressFunction } from "./Hooks/touchable-hook";
/**
 * Touchable is a low level component which implements
 * the useTouchable hook. It provides consistent hover and
 * active styles on desktop and mobile devices.
 */
export interface TouchableProps {
    onPress?: OnPressFunction;
    disabled?: boolean;
    /** By default, a touchable element will only highlight after a short
     * delay to prevent unintended highlights when scrolling. This will
     * only effect touch devices. */
    delay?: number;
    /**
     * By default, a touchable element will have an expanded press area of 20px
     * on touch devices. This will only effect touch devices.
     */
    pressExpandPx?: number;
    /** Whether active presses should be terminated when scrolling occurs. Typically this should be true. */
    terminateOnScroll?: boolean;
    component?: React.ElementType<any>;
    [key: string]: any;
}
/**
 * 旧版本 Touchable ，可注入ref的
 */
export declare const TouchRefComp: React.ForwardRefExoticComponent<Pick<TouchableProps, keyof TouchableProps> & React.RefAttributes<any>>;
/**
 * 不注入ref的版本，优化性能
 */
export declare const Touchable: React.FunctionComponent<TouchableProps>;
